Module fully_preemptive

Module fully_preemptive 

RTA for EDF scheduling with fully preemptive jobs (EDF)

Structs

Task
The per-task information required to perform the analysis.

Functions

dedicated_uniproc_rta
Bound the maximum response time of a task under fully preemptive earliest-deadline first scheduling (EDF) on a dedicated, ideal uniprocessor.

Type Aliases

InterferingTask
The per-task information required to account for interfering tasks. Create a struct of this type for each interfering task.
TaskUnderAnalysis
The information about the task under analysis required to perform the analysis. Create one struct of this type to represent the task under analysis.