search

Function search 

pub fn search<SBF, RHS>(
    supply: &SBF,
    divergence_limit: Duration,
    workload_bound: RHS,
) -> SearchResult
where SBF: SupplyBound + ?Sized, RHS: Fn(Duration) -> Service,
Iterative search for a fixed point up to a given divergence_limit, assuming a given processor supply and a generic workload bound.