rta_timer

Function rta_timer 

pub fn rta_timer<SBF, RBF1, RBF2>(
    supply: &SBF,
    own_demand: &RBF1,
    interfering_demand: &RBF2,
    blocking_bound: Service,
    limit: Duration,
) -> SearchResult
where SBF: SupplyBound + ?Sized, RBF1: RequestBound + ?Sized, RBF2: RequestBound + ?Sized,
Bound the response time of a timer callback using Lemma 3 of Casini et al. (2019).

Parameters

  • supply: the supply model of the shared executor
  • own_demand: model of the processor demand of the timer under analysis
  • interfering_demand: model of the processor demand of higher-priority timers
  • blocking_bound: a bound on the maximum delay due to lower-priority callbacks
  • limit: the divergence threshold at which the search for a fixed point is aborted

If no fixed point is found below the divergence limit given by limit, return a SearchFailure instead.