Service

Struct Service 

pub struct Service { /* private fields */ }
Type-safe alias for time values representing some amount of processor service.

Implementations

Source

impl Service

pub fn none() -> Service

Construct a service value that represents zero service.

pub fn is_none(self) -> bool

Check whether the value represents zero service.

pub const fn in_interval(d: Duration) -> Service

The amount of service received in interval of duration d (assuming a unit-service processor).

pub const fn epsilon() -> Service

The least unit of service.

pub const fn saturating_sub(&self, rhs: Service) -> Service

Subtract without under-flowing.