pub fn step_offsets(
rb: &(impl RequestBound + ?Sized),
) -> impl Iterator<Item = Offset> + '_Expand description
Yield the sequence of offsets at which the request bound function “steps”, i.e., where the procesor demand increases.
More precisely, the iterator yields values of A such that
rb.service_needed(A.since_time_zero()) < rb.service_needed(A.closed_since_time_zero())
which is equivalent to
rb.service_needed(Duration::from(A)) < rb.service_needed(Duration::from(A) + Duration::epsilon()).
It always yields A=0 since RequestBound::steps_iter
necessarily yields delta=1, which results in A=0 being the
first element yielded by step_offsets.