pub fn rta_timer<SBF, RBF1, RBF2>(
supply: &SBF,
own_demand: &RBF1,
interfering_demand: &RBF2,
blocking_bound: Service,
limit: Duration,
) -> SearchResultExpand description
Bound the response time of a timer callback using Lemma 3 of Casini et al. (2019).
Parameters
supply: the supply model of the shared executorown_demand: model of the processor demand of the timer under analysisinterfering_demand: model of the processor demand of higher-priority timersblocking_bound: a bound on the maximum delay due to lower-priority callbackslimit: the divergence threshold at which the search for a fixed point is aborted
If no fixed point is found below the divergence limit given by
limit, return a SearchFailure
instead.